div#imageEditor{
	
}

div#manageButtons{
	margin-bottom:5px;
	height:25px;
}

div#imageContainer{
    width:100%;
}

div#actionButtons div#menuHandle{
    background-color:black;
    width:100%;
    height:18px;
    margin-bottom:5px;
    cursor:move;
}

div#actionButtons{
    background-color:#f9f9f9;
    border: 2px solid black;
    width:150px;
    z-index:1001;
    padding:3px;
    position:absolute;
    margin: auto auto auto 5px;
    text-align:center;
    opacity:.9;
    left:55px;
    top:220px;
}

div#cropAndResizeButtonContainer{
    background-color:#F0EBEE;
    border:2px solid black;
    margin-bottom:2px;
    padding:2px 2px 0px 2px;
}

div#actionButtons input{
    background-repeat: no-repeat;
	padding: 1px 1px 1px 16px;
	cursor:pointer;
	border: 2px solid gray;
	background-color: #f1f1f1;
	margin:1px 5px 3px 0px;
	width:100%;
}
div.imageeditor-dialog input{
    background-repeat: no-repeat;
    background-image: url(++resource++ImageEditor.resources/icons/apply.png);
	padding: 1px 1px 1px 16px;
	cursor:pointer;
	border: 2px solid gray;
	background-color: #f1f1f1;
	margin:1px 5px 3px 0px;
}
div#actionButtons input:hover, div.imageeditor-dialog input:hover{
    background-color:white;
    border: 2px solid black;
}

div#undoRedoContainer input{
    width:48%;
    padding-left:0px;
    padding-right:0px;
    margin-left:0px;
    margin-right:0px;
	padding: 1px 1px 1px 16px;
} 

div#manageButtons input{
    background-repeat: no-repeat;
	padding: 1px 1px 1px 16px;
	cursor:pointer;
	float:left;
	margin:1px 5px 3px 0px;
}

div#actionButtons input.editing{
    border-color:black;
    background-color:gray;
    color:white;
    cursor:pointer;
}

div#actionButtons input.enabled{
    background-color:white;
    border-color:black;
    cursor:pointer;
}
div#actionButtons input.disabled{
    border-color:black;
    background-color:gray;
    color:black;
    cursor:default;
}

div#actionButtons input#crop{
	background-image: url(++resource++ImageEditor.resources/icons/stock-selection-intersect-16.png);
}
div#actionButtons input#resize{
	background-image: url(++resource++ImageEditor.resources/icons/stock-resize-16.png);
}
div#actionButtons input#rotate-left{
	background-image: url(++resource++ImageEditor.resources/icons/stock-rotate-270-16.png);
}
div#actionButtons input#rotate-right{
	background-image: url(++resource++ImageEditor.resources/icons/stock-rotate-90-16.png);
}
div#actionButtons input#apply{
	background-image: url(++resource++ImageEditor.resources/icons/apply.png);
}

div#actionButtons input#flipOnVerticalAxis{
	background-image: url(++resource++ImageEditor.resources/icons/stock-tool-rotate-16.png);
}
div#actionButtons input#flipOnHorizontalAxis{
	background-image: url(++resource++ImageEditor.resources/icons/stock-tool-flip-16.png);
}
div#actionButtons input#redo{
	background-image: url(++resource++ImageEditor.resources/icons/edit-redo.png);
}
div#actionButtons input#undo{
	background-image: url(++resource++ImageEditor.resources/icons/edit-undo.png);
}
div#actionButtons input#blur{
	background-image: url(++resource++ImageEditor.resources/icons/stock-tool-blur-16.png);
}
div#actionButtons input#compression{
    background-image: url(++resource++ImageEditor.resources/icons/stock-template-16.png);
}
div#actionButtons input#brightness{
	background-image: url(++resource++ImageEditor.resources/icons/stock-tool-brightness-16.png);
}
div#actionButtons input#contrast{
    background-image: url(++resource++ImageEditor.resources/icons/stock-tool-contrast-16.png);
}

div#actionButtons input#sharpen{
    background-image: url(++resource++ImageEditor.resources/icons/stock-tool-colorize-16.png);
}
div#actionButtons input#addDropShadow{
    background-image: url(++resource++ImageEditor.resources/icons/stock-transparency-16.png);
}

div.imageeditor-dialog p{
    margin-bottom:15px;
    font-weight:bold;
}

.ui-slider {
    background-color: #E1D9F5;
    width:200px;
    margin-top:6px;
}

.ui-resizable-handle{
    z-index: 1000;
}

.ui-slider-handle {
    background-color: #f9f9f9;
    border-color:gray;
}

.ui-slider-handle:hover{
    border-color:gray;
}

.imageeditor-slider{
    float:left;
    margin-right:13px;
}

.imageeditor-slider p{
    padding-left:45%;
    position:relative;
    top:-20px;
}
div.imageeditor-dialog .imageeditor-slider p{
    padding-left:45%;
    top:-20px;
    font-weight:normal;
}

.ui-dialog-content {
    padding:10px;
}

div#image-cropper-aspect-selector{
    position:relative;
    left:16px;
}
div#image-cropper-aspect-selector input{
    float:left;
    width:75px;
    height:20px;
    margin:5px;
    cursor:pointer;
}
div#image-cropper-aspect-selector input.selected{
    border: 2px solid orange;
    color:black;
    cursor:default;
}